//
// Program written by Daniel Audet
//
// This program creates a Bezier patch using 16 control points defined 
// as shown in the file named "bezier-surface.jpg" located in the same 
// folder as this program.
//

"use strict";

var gl;   // The webgl context.

var CoordsLoc;       // Location of the coords attribute variable in the standard texture mappping shader program.
var NormalLoc;
var TexCoordLoc;

var ProjectionLoc;     // Location of the uniform variables in the standard texture mappping shader program.
var ModelviewLoc;
var NormalMatrixLoc;


var projection;   //--- projection matrix
var modelview;    // modelview matrix
var flattenedmodelview;    //--- flattened modelview matrix

var normalMatrix = mat3();  //--- create a 3X3 matrix that will affect normals

var rotator;   // A SimpleRotator object to enable rotation by mouse dragging.

var sphere, bezierpatch;  // model identifiers

var prog;  // shader program identifier

var lightPosition = vec4(20.0, 20.0, 100.0, 1.0);

var lightAmbient = vec4(1.0, 1.0, 1.0, 1.0);
var lightDiffuse = vec4(1.0, 1.0, 1.0, 1.0);
var lightSpecular = vec4(1.0, 1.0, 1.0, 1.0);

var materialAmbient = vec4(0.0, 0.1, 0.3, 1.0);
var materialDiffuse = vec4(0.48, 0.55, 0.69, 1.0);
var materialSpecular = vec4(0.48, 0.55, 0.69, 1.0);
var materialShininess = 100.0;

var ambientProduct, diffuseProduct, specularProduct;

var controlpoints = [];
var p00;
var p01;
var p02;
var p03;

var p10;
var p11;
var p12;
var p13;

var p20;
var p21;
var p22;
var p23;

var p30;
var p31;	
var p32;
var p33;

var currentU = 0, currentV = 0;

function render() {
    gl.clearColor(0.79, 0.76, 0.27, 1);
    gl.clear(gl.COLOR_BUFFER_BIT | gl.DEPTH_BUFFER_BIT);

    //--- Get the rotation matrix obtained by the displacement of the mouse
    //---  (note: the matrix obtained is already "flattened" by the function getViewMatrix)
    flattenedmodelview = rotator.getViewMatrix();
    modelview = unflatten(flattenedmodelview);

	normalMatrix = extractNormalMatrix(modelview);
		
    var initialmodelview = modelview;

    //  now, draw sphere model
    modelview = initialmodelview;
    modelview = mult(modelview, translate(controlpoints[currentV][currentU][0],controlpoints[currentV][currentU][1],controlpoints[currentV][currentU][2]));
    normalMatrix = extractNormalMatrix(modelview);  // always extract the normal matrix before scaling
    sphere.render();
	
	//  now, draw the bezier patch model
    modelview = initialmodelview;
    modelview = mult(modelview, translate(0.0, 0.0, 0.0));
    modelview = mult(modelview, rotate(0.0, 1, 0, 0));
    normalMatrix = extractNormalMatrix(modelview);  // always extract the normal matrix before scaling
    bezierpatch.render();
	
	}

function createBezierPatch(controlpoints, nsubdivisions) {

   var coords = [];
   var normals = [];
   var texCoords = [];
   var indices = [];
   
	var u, v, i, j, k;
	var sum = [];
	var newpoint = [];
	var tmp1 = [];
	var tmp2 = [];
	var bu = [];
	var bv = [];
	var v1 = [];
	var v2 = [];
	var v3 = [];
	var vector1 = [];
	var vector2 = [];
	var localnormal = [];
	var increment;
	
	increment = 1.0/nsubdivisions;
	
	for(v=0; v<1+increment/2; v += increment){ // adding "increment/2" to "1" guarantees that we compute the last one (precision problem)
		bv = blending(v);
		for(u=0; u<1+increment/2; u += increment){  // adding "increment/2" to "1" guarantees that we compute the last one (precision problem)
			bu = blending(u);

			// clear array
			sum.length= 0;

			// compute the double summation
			
			// multiply each point of a row (of 4 consecutive control points in the "u" direction)
			// with the corresponding blending factor (one element of the "bu" vector)

			for(i=0; i<=3; i++){  // the row is selected using "i"
					tmp1.length=0;  // clear array
					for(j=0; j<=3; j++){ // each control point in the "u" direction is selected using "j"
						// remember that controlpoints[0] contains the 4 control points p00, p01, p02 and p03
						// etc...
						tmp1.push(scalevector( bu[j], controlpoints[i][j]));  // this generates 4 new points
					}
					tmp2 = tmp1[0];  // store the first point
					for(k=1; k<=3; k++){ // add the other 3 points to obtain the first sum
						tmp2 = add(tmp2, tmp1[k]);
					}
					sum.push(tmp2);  // store the resulting sum (that is one point)
			}
			
			// do it again for the 4 resulting sums obtained above.
			// multiply each resulting sum with the corresponding blending function (this time "bv")
			for(i=0; i<=3; i++){  // the row is selected using "i"
					tmp1.length=0;  // clear array
					for(j=0; j<=3; j++){  // each point obtained previously (in "sum") is selected using "j"			
						tmp1.push(scalevector( bv[j], sum[j]));   // this generates 4 new points
					}
					tmp2 = tmp1[0];  // store the first point
					for(k=1; k<=3; k++){ // add the other 3 points
						tmp2 = add(tmp2, tmp1[k]);
					}
			}
			// store the final result (one point) in "coords"
			coords.push(tmp2[0], tmp2[1], tmp2[2]);
		}
	}
	
	// create the mesh
	var indexrange;
	var nrows = nsubdivisions + 1;
	for(j=0; j<nrows-1; j++){  // travel in the "v" direction
		for(i=0; i<nrows-1; i++){  // travel in the "u" direction
			indices.push(i+j*nrows,i+j*nrows+1,i+j*nrows+nrows,     i+j*nrows+1,i+j*nrows+nrows+1,i+j*nrows+nrows);
			indexrange = (nrows-1);
			texCoords.push(i/indexrange,j/indexrange,    (i+1)/indexrange,j/indexrange,   i/indexrange,(j+1)/indexrange,
								(i+1)/indexrange,j/indexrange,    (i+1)/indexrange,(j+1)/indexrange,   i/indexrange,(j+1)/indexrange
							);
							
			// compute the local normal for each point of the mesh
			// using the first triangle defined above 
			//  -> first get the x,y,z values of each of the three vertices v1, v2 and v3)
			//  -> then compute the two vectors
			//  -> finally compute normal
			
			v1.push(coords[3*(i+j*nrows)]);		// x value
			v1.push(coords[3*(i+j*nrows) + 1]);	// y value
			v1.push(coords[3*(i+j*nrows) + 2]);	// z value
			
			v2.push(coords[3*(i+j*nrows+1)]);
			v2.push(coords[3*(i+j*nrows+1) + 1]);
			v2.push(coords[3*(i+j*nrows+1) + 2]);
			
			v3.push(coords[3*(i+j*nrows+nrows)]);
			v3.push(coords[3*(i+j*nrows+nrows) + 1]);
			v3.push(coords[3*(i+j*nrows+nrows) + 2]);

			vector1 = subtract(v2, v1);
			vector2 = subtract(v3, v1);
			localnormal = normalize(cross(vector1, vector2));
			normals.push(localnormal[0], localnormal[1], localnormal[2]);	// remember: there must be as many normals as vertices
																			// (the indices select the normals)
			// clear array
			v1.length = 0;
			v2.length = 0;
			v3.length = 0;
			
			if(i == nrows-2){  // in the last iteration of the loop, add the normal of the last point in the row (we use the other triangle)

				v1.push(coords[3*(i+j*nrows+1)]);
				v1.push(coords[3*(i+j*nrows+1) + 1]);
				v1.push(coords[3*(i+j*nrows+1) + 2]);
				
				v2.push(coords[3*(i+j*nrows+nrows+1)]);
				v2.push(coords[3*(i+j*nrows+nrows+1) + 1]);
				v2.push(coords[3*(i+j*nrows+nrows+1) + 2]);
				
				v3.push(coords[3*(i+j*nrows+nrows)]);
				v3.push(coords[3*(i+j*nrows+nrows) + 1]);
				v3.push(coords[3*(i+j*nrows+nrows) + 2]);
				
				vector1 = subtract(v2, v1);
				vector2 = subtract(v3, v1);
				localnormal = normalize(cross(vector1, vector2));
				normals.push(localnormal[0], localnormal[1], localnormal[2]);
				// clear array
				v1.length = 0;
				v2.length = 0;
				v3.length = 0;	
			}
			
		}		
	}
	

	// add the normals of the last row (in the v direction)
	// (we use the other triangle)
	for(i=0; i<nrows-1; i++){  // travel in the "u" direction
		v1.push(coords[3*(i+(nrows-1)*nrows)]);
		v1.push(coords[3*(i+(nrows-1)*nrows) + 1]);
		v1.push(coords[3*(i+(nrows-1)*nrows) + 2]);
		
		v2.push(coords[3*(i+(nrows-2)*nrows+1)]);
		v2.push(coords[3*(i+(nrows-2)*nrows+1) + 1]);
		v2.push(coords[3*(i+(nrows-2)*nrows+1) + 2]);
		
		v3.push(coords[3*(i+(nrows-1)*nrows+1)]);
		v3.push(coords[3*(i+(nrows-1)*nrows+1) + 1]);
		v3.push(coords[3*(i+(nrows-1)*nrows+1) + 2]);
		
		vector1 = subtract(v2, v1);
		vector2 = subtract(v3, v1);
		localnormal = normalize(cross(vector1, vector2));
		normals.push(localnormal[0], localnormal[1], localnormal[2]);
		// clear array
		v1.length = 0;
		v2.length = 0;
		v3.length = 0;
	}

	// for the very last point, use the same normal as the previous vertice (since same triangle)
	normals.push(localnormal[0], localnormal[1], localnormal[2]);

	
   return {
      vertexPositions: new Float32Array(coords),
      vertexNormals: new Float32Array(normals),
      vertexTextureCoords: new Float32Array(texCoords),
      indices: new Uint16Array(indices)
   }
}

function blending(u) {
    var b = [];
    var a = 1-u;

    b.push(a*a*a);
    b.push(3*a*a*u);
    b.push(3*a*u*u);
    b.push(u*u*u);
    return b;
}

function unflatten(matrix) {
    var result = mat4();
    result[0][0] = matrix[0]; result[1][0] = matrix[1]; result[2][0] = matrix[2]; result[3][0] = matrix[3];
    result[0][1] = matrix[4]; result[1][1] = matrix[5]; result[2][1] = matrix[6]; result[3][1] = matrix[7];
    result[0][2] = matrix[8]; result[1][2] = matrix[9]; result[2][2] = matrix[10]; result[3][2] = matrix[11];
    result[0][3] = matrix[12]; result[1][3] = matrix[13]; result[2][3] = matrix[14]; result[3][3] = matrix[15];

    return result;
}

function extractNormalMatrix(matrix) { // This function computes the transpose of the inverse of 
    // the upperleft part (3X3) of the modelview matrix (see http://www.lighthouse3d.com/tutorials/glsl-tutorial/the-normal-matrix/ )

    var result = mat3();
    var upperleft = mat3();
    var tmp = mat3();

    upperleft[0][0] = matrix[0][0];  // if no scaling is performed, one can simply use the upper left
    upperleft[1][0] = matrix[1][0];  // part (3X3) of the modelview matrix
    upperleft[2][0] = matrix[2][0];

    upperleft[0][1] = matrix[0][1];
    upperleft[1][1] = matrix[1][1];
    upperleft[2][1] = matrix[2][1];

    upperleft[0][2] = matrix[0][2];
    upperleft[1][2] = matrix[1][2];
    upperleft[2][2] = matrix[2][2];

    tmp = matrixinvert(upperleft);
    result = transpose(tmp);

    return result;
}

function matrixinvert(matrix) {

    var result = mat3();

    var det = matrix[0][0] * (matrix[1][1] * matrix[2][2] - matrix[2][1] * matrix[1][2]) -
                 matrix[0][1] * (matrix[1][0] * matrix[2][2] - matrix[1][2] * matrix[2][0]) +
                 matrix[0][2] * (matrix[1][0] * matrix[2][1] - matrix[1][1] * matrix[2][0]);

    var invdet = 1 / det;

    // inverse of matrix m
    result[0][0] = (matrix[1][1] * matrix[2][2] - matrix[2][1] * matrix[1][2]) * invdet;
    result[0][1] = (matrix[0][2] * matrix[2][1] - matrix[0][1] * matrix[2][2]) * invdet;
    result[0][2] = (matrix[0][1] * matrix[1][2] - matrix[0][2] * matrix[1][1]) * invdet;
    result[1][0] = (matrix[1][2] * matrix[2][0] - matrix[1][0] * matrix[2][2]) * invdet;
    result[1][1] = (matrix[0][0] * matrix[2][2] - matrix[0][2] * matrix[2][0]) * invdet;
    result[1][2] = (matrix[1][0] * matrix[0][2] - matrix[0][0] * matrix[1][2]) * invdet;
    result[2][0] = (matrix[1][0] * matrix[2][1] - matrix[2][0] * matrix[1][1]) * invdet;
    result[2][1] = (matrix[2][0] * matrix[0][1] - matrix[0][0] * matrix[2][1]) * invdet;
    result[2][2] = (matrix[0][0] * matrix[1][1] - matrix[1][0] * matrix[0][1]) * invdet;

    return result;
}

// The following function is used to create an "object" (called "model") containing all the informations needed
// to draw a particular element (sphere, cylinder, cube,...). 
// Note that the function "model.render" is defined inside "createModel" but it is NOT executed.
// That function is only executed when we call it explicitly in render().

function createModel(modelData) {

	// the next line defines an "object" in Javascript
	// (note that there are several ways to define an "object" in Javascript)
	var model = {};
	
	// the following lines defines "members" of the "object"
    model.coordsBuffer = gl.createBuffer();
    model.normalBuffer = gl.createBuffer();
    model.textureBuffer = gl.createBuffer();
    model.indexBuffer = gl.createBuffer();
    model.count = modelData.indices.length;

	// the "members" are then used to load data from "modelData" in the graphic card
    gl.bindBuffer(gl.ARRAY_BUFFER, model.coordsBuffer);
    gl.bufferData(gl.ARRAY_BUFFER, modelData.vertexPositions, gl.STATIC_DRAW);
    gl.bindBuffer(gl.ARRAY_BUFFER, model.normalBuffer);
    gl.bufferData(gl.ARRAY_BUFFER, modelData.vertexNormals, gl.STATIC_DRAW);
    gl.bindBuffer(gl.ARRAY_BUFFER, model.textureBuffer);
    gl.bufferData(gl.ARRAY_BUFFER, modelData.vertexTextureCoords, gl.STATIC_DRAW);
    gl.bindBuffer(gl.ELEMENT_ARRAY_BUFFER, model.indexBuffer);
    gl.bufferData(gl.ELEMENT_ARRAY_BUFFER, modelData.indices, gl.STATIC_DRAW);

	// The following function is NOT executed here. It is only DEFINED to be used later when we
	// call the ".render()" method.
    model.render = function () {
        gl.bindBuffer(gl.ARRAY_BUFFER, this.coordsBuffer);
        gl.vertexAttribPointer(CoordsLoc, 3, gl.FLOAT, false, 0, 0);
        gl.bindBuffer(gl.ARRAY_BUFFER, this.normalBuffer);
        gl.vertexAttribPointer(NormalLoc, 3, gl.FLOAT, false, 0, 0);
        gl.bindBuffer(gl.ARRAY_BUFFER, this.textureBuffer);
        gl.vertexAttribPointer(TexCoordLoc, 2, gl.FLOAT, false, 0, 0);

        gl.bindBuffer(gl.ELEMENT_ARRAY_BUFFER, this.indexBuffer);

        gl.uniformMatrix4fv(ModelviewLoc, false, flatten(modelview));    //--- load flattened modelview matrix
        gl.uniformMatrix3fv(NormalMatrixLoc, false, flatten(normalMatrix));  //--- load flattened normal matrix

        gl.drawElements(gl.TRIANGLES, this.count, gl.UNSIGNED_SHORT, 0);
        console.log(this.count);
    }
	
	// we now return the "object".
    return model;
}



function createProgram(gl, vertexShaderSource, fragmentShaderSource) {
    var vsh = gl.createShader(gl.VERTEX_SHADER);
    gl.shaderSource(vsh, vertexShaderSource);
    gl.compileShader(vsh);
    if (!gl.getShaderParameter(vsh, gl.COMPILE_STATUS)) {
        throw "Error in vertex shader:  " + gl.getShaderInfoLog(vsh);
    }
    var fsh = gl.createShader(gl.FRAGMENT_SHADER);
    gl.shaderSource(fsh, fragmentShaderSource);
    gl.compileShader(fsh);
    if (!gl.getShaderParameter(fsh, gl.COMPILE_STATUS)) {
        throw "Error in fragment shader:  " + gl.getShaderInfoLog(fsh);
    }
    var prog = gl.createProgram();
    gl.attachShader(prog, vsh);
    gl.attachShader(prog, fsh);
    gl.linkProgram(prog);
    if (!gl.getProgramParameter(prog, gl.LINK_STATUS)) {
        throw "Link error in program:  " + gl.getProgramInfoLog(prog);
    }
    return prog;
}


function getTextContent(elementID) {
    var element = document.getElementById(elementID);
    var fsource = "";
    var node = element.firstChild;
    var str = "";
    while (node) {
        if (node.nodeType == 3) // this is a text node
            str += node.textContent;
        node = node.nextSibling;
    }
    return str;
}


window.onload = function init() {
    try {
        var canvas = document.getElementById("glcanvas");
        gl = canvas.getContext("webgl");
        if (!gl) {
            gl = canvas.getContext("experimental-webgl");
        }
        if (!gl) {
            throw "Could not create WebGL context.";
        }

        // LOAD SHADER (standard texture mapping)
        var vertexShaderSource = getTextContent("vshader");
        var fragmentShaderSource = getTextContent("fshader");
        prog = createProgram(gl, vertexShaderSource, fragmentShaderSource);

        gl.useProgram(prog);

        // locate variables for further use
        CoordsLoc = gl.getAttribLocation(prog, "vcoords");
        NormalLoc = gl.getAttribLocation(prog, "vnormal");
        TexCoordLoc = gl.getAttribLocation(prog, "vtexcoord");

        ModelviewLoc = gl.getUniformLocation(prog, "modelview");
        ProjectionLoc = gl.getUniformLocation(prog, "projection");
        NormalMatrixLoc = gl.getUniformLocation(prog, "normalMatrix");

        gl.enableVertexAttribArray(CoordsLoc);
        gl.enableVertexAttribArray(NormalLoc);
		gl.disableVertexAttribArray(TexCoordLoc);  // we do not need texture coordinates

        gl.enable(gl.DEPTH_TEST);

        //  create a "rotator" monitoring mouse mouvement
        rotator = new SimpleRotator(canvas, render);
        //  set initial camera position at z=40, with an "up" vector aligned with y axis
        //   (this defines the initial value of the modelview matrix )
        rotator.setView([0, 0, 1], [0, 1, 0], 40);

        ambientProduct = mult(lightAmbient, materialAmbient);
        diffuseProduct = mult(lightDiffuse, materialDiffuse);
        specularProduct = mult(lightSpecular, materialSpecular);
		
		gl.uniform4fv(gl.getUniformLocation(prog, "ambientProduct"), flatten(ambientProduct));
		gl.uniform4fv(gl.getUniformLocation(prog, "diffuseProduct"), flatten(diffuseProduct));
		gl.uniform4fv(gl.getUniformLocation(prog, "specularProduct"), flatten(specularProduct));
		gl.uniform1f(gl.getUniformLocation(prog, "shininess"), materialShininess);

		gl.uniform4fv(gl.getUniformLocation(prog, "lightPosition"), flatten(lightPosition));

		projection = perspective(70.0, 1.0, 1.0, 200.0);
		gl.uniformMatrix4fv(ProjectionLoc, false, flatten(projection));  // send projection matrix to the shader program
		
		// In the following lines, we create different "elements" (sphere, cylinder, box, disk,...).
		// These elements are "objects" returned by the "createModel()" function.
		// The "createModel()" function requires one parameter which contains all the information needed
		// to create the "object". The functions "uvSphere()", "uvCylinder()", "cube()",... are described
		// in the file "basic-objects-IFS.js". They return an "object" containing vertices, normals, 
		// texture coordinates and indices.
		// 
		
        sphere = createModel(uvSphere(0.5, 25.0, 25.0));
 
		// Dans la liste de points suivantes, les chiffres apparaissant après "p" sont associés aux directions "u" et "v". 
		// Ainsi, la série de points de contrôle p00, p01, p02 et p03 sont "alignés" dans la direction "u".
		// Et la série de points de contrôle P00, p10, p20 et p30 sont "alignés" dans la direction "v".
		// Voir fichier "bezier-surface.jpg" situé dans le même dossier que le présent fichier Javascript.
		p00 = [-12, 0, 0, 1];  // p00 = [-12, 0, 0, 1];
		p01 = [-4, 0, 0, 1];   // p01 = [-4, 0, 0, 1];
		p02 = [ 4, 8, 0, 1];   // p02 = [ 4, 8, 0, 1];
		p03 = [ 12, 0, 0, 1];  // p03 = [ 12, 0, 0, 1];

		p10 = [-12, 0, -8, 1];
		p11 = [-4, 0, -8, 1];
		p12 = [ 4, 0, -8, 1];
		p13 = [ 12, 0, -8, 1];

		p20 = [-12, 0, -16, 1];
		p21 = [-4, 20, -16, 1];
		p22 = [ 4, 0, -16, 1];
		p23 = [ 12, 0, -16, 1];

		p30 = [-12, 0, -24, 1];
		p31 = [-4, 0, -24, 1];	
		p32 = [ 4, 0, -24, 1];
		p33 = [ 12, 0, -24, 1];
		
		var p0 = [];
		var p1 = [];
		var p2 = [];
		var p3 = [];
		
		p0.push(p00);
		p0.push(p01);
		p0.push(p02);
		p0.push(p03);
		p1.push(p10);
		p1.push(p11);
		p1.push(p12);
		p1.push(p13);
		p2.push(p20);
		p2.push(p21);
		p2.push(p22);
		p2.push(p23);
		p3.push(p30);
		p3.push(p31);
		p3.push(p32);
		p3.push(p33);

		controlpoints.push(p0);  // thus, controlpoints[0] contains the 4 control points p00, p01, p02 and p03
		controlpoints.push(p1);
		controlpoints.push(p2);
		controlpoints.push(p3);
		
		bezierpatch = createModel(createBezierPatch(controlpoints, 19));
 
		// managing the buttons
		document.getElementById("P00").onclick = function () {
			currentU = 0;
			currentV = 0;
			render();
			};
		document.getElementById("P01").onclick = function () {
			currentU = 1;
			currentV = 0;
			render();
			};
		document.getElementById("P02").onclick = function () {
			currentU = 2;
			currentV = 0;
			render();
			};
		document.getElementById("P03").onclick = function () {
			currentU = 3;
			currentV = 0;
			render();
			};
		document.getElementById("P10").onclick = function () {
			currentU = 0;
			currentV = 1;
			render();
			};
		document.getElementById("P11").onclick = function () {
			currentU = 1;
			currentV = 1;
			render();
			};
		document.getElementById("P12").onclick = function () {
			currentU = 2;
			currentV = 1;
			render();
			};
		document.getElementById("P13").onclick = function () {
			currentU = 3;
			currentV = 1;
			render();
			};
		document.getElementById("P20").onclick = function () {
			currentU = 0;
			currentV = 2;
			render();
			};
		document.getElementById("P21").onclick = function () {
			currentU = 1;
			currentV = 2;
			render();
			};
		document.getElementById("P22").onclick = function () {
			currentU = 2;
			currentV = 2;
			render();
			};
		document.getElementById("P23").onclick = function () {
			currentU = 3;
			currentV = 2;
			render();
			};
		document.getElementById("P30").onclick = function () {
			currentU = 0;
			currentV = 3;
			render();
			};
		document.getElementById("P31").onclick = function () {
			currentU = 1;
			currentV = 3;
			render();
			};
		document.getElementById("P32").onclick = function () {
			currentU = 2;
			currentV = 3;
			render();
			};
		document.getElementById("P33").onclick = function () {
			currentU = 3;
			currentV = 3;
			render();
			};
		
 		// managing arrow keys (to move the control point)
		document.onkeydown = function (e) {
			switch (e.key) {
				case 'ArrowUp':
					// up arrow
					controlpoints[currentV][currentU] = add( [0,1,0,0], controlpoints[currentV][currentU]);
					bezierpatch = createModel(createBezierPatch(controlpoints, 19));
					render();
					break;
				case 'ArrowDown':
					// down arrow
					controlpoints[currentV][currentU] = add( [0,-1,0,0], controlpoints[currentV][currentU]);
					bezierpatch = createModel(createBezierPatch(controlpoints, 19));
					render();
					break;
				case 'ArrowLeft':
					// left arrow
					controlpoints[currentV][currentU] = add( [-1,0,0,0], controlpoints[currentV][currentU]);
					bezierpatch = createModel(createBezierPatch(controlpoints, 19));
					render();
					break;
				case 'ArrowRight':
					// right arrow
					controlpoints[currentV][currentU] = add( [1,0,0,0], controlpoints[currentV][currentU]);
					bezierpatch = createModel(createBezierPatch(controlpoints, 19));
					render();
					break;
				case 'PageUp':
					// page up
					controlpoints[currentV][currentU] = add( [0,0,1,0], controlpoints[currentV][currentU]);
					bezierpatch = createModel(createBezierPatch(controlpoints, 19));
					render();
					break;
				case 'PageDown':
					// page down
					controlpoints[currentV][currentU] = add( [0,0,-1,0], controlpoints[currentV][currentU]);
					bezierpatch = createModel(createBezierPatch(controlpoints, 19));
					render();
					break;
				case 'Home':
					// maximize canvas size
					resize(canvas);
					break;
			}
		};

 
 

    }
    catch (e) {
        document.getElementById("message").innerHTML =
             "Could not initialize WebGL: " + e;
        return;
    }

	resize(canvas);  // size the canvas to the current window width and height

    render();
}

function resize(canvas) {  // ref. https://webglfundamentals.org/webgl/lessons/webgl-resizing-the-canvas.html
  // var realToCSSPixels = window.devicePixelRatio;

  // var actualPanelWidth = Math.floor(0.85 * window.innerWidth * realToCSSPixels); // because, in the HTML file, we have set the right panel to be 85% of the window width
  // var actualPanelHeight = Math.floor(0.96 * window.innerHeight * realToCSSPixels); 

  var actualPanelWidth = Math.floor(0.85 * window.innerWidth); // because, in the HTML file, we have set the right panel to be 85% of the window width
  var actualPanelHeight = Math.floor(0.96 * window.innerHeight); 

  
  var minDimension = Math.min(actualPanelWidth, actualPanelHeight);
    
   // Ajust the canvas to this dimension (square)
    canvas.width  = minDimension;
    canvas.height = minDimension;
	
	gl.viewport(0, 0, canvas.width, canvas.height);

}



